@@ -3,7 +3,6 @@
 from __future__ import annotations
 
 import contextlib
-from os import path
 from re import DOTALL, match
 from textwrap import indent
 from typing import TYPE_CHECKING, Any, TypeVar
@@ -48,8 +47,14 @@ EXCLUDED_PENDING_XREF_ATTRIBUTES = ('refexplicit',)
 N = TypeVar('N', bound=nodes.Node)
 
 
-def publish_msgstr(app: Sphinx, source: str, source_path: str, source_line: int,
-                   config: Config, settings: Any) -> nodes.Element:
+def publish_msgstr(
+    app: Sphinx,
+    source: str,
+    source_path: str,
+    source_line: int,
+    config: Config,
+    settings: Any,
+) -> nodes.Element:
     """Publish msgstr (single line) into docutils document
 
     :param sphinx.application.Sphinx app: sphinx application
@@ -67,13 +72,15 @@ def publish_msgstr(app: Sphinx, source: str, source_path: str, source_line: int,
         config.rst_prolog = None
 
         from sphinx.io import SphinxI18nReader
+
         reader = SphinxI18nReader()
         reader.setup(app)
         filetype = get_filetype(config.source_suffix, source_path)
         parser = app.registry.create_source_parser(app, filetype)
         doc = reader.read(
-            source=StringInput(source=source,
-                               source_path=f"{source_path}:{source_line}:<translated>"),
+            source=StringInput(
+                source=source, source_path=f'{source_path}:{source_line}:<translated>'
+            ),
             parser=parser,
             settings=settings,
         )
@@ -85,7 +92,7 @@ def publish_msgstr(app: Sphinx, source: str, source_path: str, source_line: int,
 
 
 def parse_noqa(source: str) -> tuple[str, bool]:
-    m = match(r"(.*)(?<!\\)#\s*noqa\s*$", source, DOTALL)
+    m = match(r'(.*)(?<!\\)#\s*noqa\s*$', source, DOTALL)
     if m:
         return m.group(1), True
     else:
@@ -93,9 +100,7 @@ def parse_noqa(source: str) -> tuple[str, bool]:
 
 
 class PreserveTranslatableMessages(SphinxTransform):
-    """
-    Preserve original translatable messages before translation
-    """
+    """Preserve original translatable messages before translation"""
 
     default_priority = 10  # this MUST be invoked before Locale transform
 
@@ -108,29 +113,43 @@ class _NodeUpdater:
     """Contains logic for updating one node with the translated content."""
 
     def __init__(
-        self, node: nodes.Element, patch: nodes.Element, document: nodes.document, noqa: bool,
+        self,
+        node: nodes.Element,
+        patch: nodes.Element,
+        document: nodes.document,
+        noqa: bool,
     ) -> None:
         self.node: nodes.Element = node
         self.patch: nodes.Element = patch
         self.document: nodes.document = document
         self.noqa: bool = noqa
 
-    def compare_references(self, old_refs: Sequence[nodes.Element],
-                           new_refs: Sequence[nodes.Element],
-                           warning_msg: str) -> None:
+    def compare_references(
+        self,
+        old_refs: Sequence[nodes.Element],
+        new_refs: Sequence[nodes.Element],
+        warning_msg: str,
+    ) -> None:
         """Warn about mismatches between references in original and translated content."""
         # FIXME: could use a smarter strategy than len(old_refs) == len(new_refs)
         if not self.noqa and len(old_refs) != len(new_refs):
             old_ref_rawsources = [ref.rawsource for ref in old_refs]
             new_ref_rawsources = [ref.rawsource for ref in new_refs]
-            logger.warning(warning_msg.format(old_ref_rawsources, new_ref_rawsources),
-                           location=self.node, type='i18n', subtype='inconsistent_references')
+            logger.warning(
+                warning_msg.format(old_ref_rawsources, new_ref_rawsources),
+                location=self.node,
+                type='i18n',
+                subtype='inconsistent_references',
+            )
 
     def update_title_mapping(self) -> bool:
         processed = False  # skip flag
 
         # update title(section) target name-id mapping
-        if isinstance(self.node, nodes.title) and isinstance(self.node.parent, nodes.section):
+        if (
+            isinstance(self.node, nodes.title)
+            and isinstance(self.node.parent, nodes.section)
+        ):  # fmt: skip
             section_node = self.node.parent
             new_name = nodes.fully_normalize_name(self.patch.astext())
             old_name = nodes.fully_normalize_name(self.node.astext())
@@ -201,9 +220,14 @@ class _NodeUpdater:
         is_autofootnote_ref = NodeMatcher(nodes.footnote_reference, auto=Any)
         old_foot_refs = list(is_autofootnote_ref.findall(self.node))
         new_foot_refs = list(is_autofootnote_ref.findall(self.patch))
-        self.compare_references(old_foot_refs, new_foot_refs,
-                                __('inconsistent footnote references in translated message.' +
-                                   ' original: {0}, translated: {1}'))
+        self.compare_references(
+            old_foot_refs,
+            new_foot_refs,
+            __(
+                'inconsistent footnote references in translated message.'
+                ' original: {0}, translated: {1}'
+            ),
+        )
         old_foot_namerefs: dict[str, list[nodes.footnote_reference]] = {}
         for r in old_foot_refs:
             old_foot_namerefs.setdefault(r.get('refname'), []).append(r)
@@ -241,9 +265,14 @@ class _NodeUpdater:
         is_refnamed_ref = NodeMatcher(nodes.reference, refname=Any)
         old_refs = list(is_refnamed_ref.findall(self.node))
         new_refs = list(is_refnamed_ref.findall(self.patch))
-        self.compare_references(old_refs, new_refs,
-                                __('inconsistent references in translated message.' +
-                                   ' original: {0}, translated: {1}'))
+        self.compare_references(
+            old_refs,
+            new_refs,
+            __(
+                'inconsistent references in translated message.'
+                ' original: {0}, translated: {1}'
+            ),
+        )
         old_ref_names = [r['refname'] for r in old_refs]
         new_ref_names = [r['refname'] for r in new_refs]
         orphans = [*({*old_ref_names} - {*new_ref_names})]
@@ -266,31 +295,41 @@ class _NodeUpdater:
         old_foot_refs = list(is_refnamed_footnote_ref.findall(self.node))
         new_foot_refs = list(is_refnamed_footnote_ref.findall(self.patch))
         refname_ids_map: dict[str, list[str]] = {}
-        self.compare_references(old_foot_refs, new_foot_refs,
-                                __('inconsistent footnote references in translated message.' +
-                                   ' original: {0}, translated: {1}'))
+        self.compare_references(
+            old_foot_refs,
+            new_foot_refs,
+            __(
+                'inconsistent footnote references in translated message.'
+                ' original: {0}, translated: {1}'
+            ),
+        )
         for oldf in old_foot_refs:
-            refname_ids_map.setdefault(oldf["refname"], []).append(oldf["ids"])
+            refname_ids_map.setdefault(oldf['refname'], []).append(oldf['ids'])
         for newf in new_foot_refs:
-            refname = newf["refname"]
+            refname = newf['refname']
             if refname_ids_map.get(refname):
-                newf["ids"] = refname_ids_map[refname].pop(0)
+                newf['ids'] = refname_ids_map[refname].pop(0)
 
     def update_citation_references(self) -> None:
         # citation should use original 'ids'.
         is_citation_ref = NodeMatcher(nodes.citation_reference, refname=Any)
         old_cite_refs = list(is_citation_ref.findall(self.node))
         new_cite_refs = list(is_citation_ref.findall(self.patch))
-        self.compare_references(old_cite_refs, new_cite_refs,
-                                __('inconsistent citation references in translated message.' +
-                                   ' original: {0}, translated: {1}'))
+        self.compare_references(
+            old_cite_refs,
+            new_cite_refs,
+            __(
+                'inconsistent citation references in translated message.'
+                ' original: {0}, translated: {1}'
+            ),
+        )
         refname_ids_map: dict[str, list[str]] = {}
         for oldc in old_cite_refs:
-            refname_ids_map.setdefault(oldc["refname"], []).append(oldc["ids"])
+            refname_ids_map.setdefault(oldc['refname'], []).append(oldc['ids'])
         for newc in new_cite_refs:
-            refname = newc["refname"]
+            refname = newc['refname']
             if refname_ids_map.get(refname):
-                newc["ids"] = refname_ids_map[refname].pop()
+                newc['ids'] = refname_ids_map[refname].pop()
 
     def update_pending_xrefs(self) -> None:
         # Original pending_xref['reftarget'] contain not-translated
@@ -298,20 +337,25 @@ class _NodeUpdater:
         # This code restricts to change ref-targets in the translation.
         old_xrefs = [*self.node.findall(addnodes.pending_xref)]
         new_xrefs = [*self.patch.findall(addnodes.pending_xref)]
-        self.compare_references(old_xrefs, new_xrefs,
-                                __('inconsistent term references in translated message.' +
-                                   ' original: {0}, translated: {1}'))
+        self.compare_references(
+            old_xrefs,
+            new_xrefs,
+            __(
+                'inconsistent term references in translated message.'
+                ' original: {0}, translated: {1}'
+            ),
+        )
 
         xref_reftarget_map: dict[tuple[str, str, str] | None, dict[str, Any]] = {}
 
         def get_ref_key(node: addnodes.pending_xref) -> tuple[str, str, str] | None:
-            case = node["refdomain"], node["reftype"]
+            case = node['refdomain'], node['reftype']
             if case == ('std', 'term'):
                 return None
             else:
                 return (
-                    node["refdomain"],
-                    node["reftype"],
+                    node['refdomain'],
+                    node['reftype'],
                     node['reftarget'],
                 )
 
@@ -334,9 +378,7 @@ class _NodeUpdater:
 
 
 class Locale(SphinxTransform):
-    """
-    Replace translatable nodes with their translated doctree.
-    """
+    """Replace translatable nodes with their translated doctree."""
 
     default_priority = 20
 
@@ -347,8 +389,8 @@ class Locale(SphinxTransform):
         textdomain = docname_to_domain(self.env.docname, self.config.gettext_compact)
 
         # fetch translations
-        dirs = [path.join(self.env.srcdir, directory)
-                for directory in self.config.locale_dirs]
+        srcdir = self.env.srcdir
+        dirs = [srcdir / directory for directory in self.config.locale_dirs]
         catalog, has_catalog = init_locale(dirs, self.config.language, textdomain)
         if not has_catalog:
             return
@@ -371,7 +413,7 @@ class Locale(SphinxTransform):
             if not isinstance(node, LITERAL_TYPE_NODES):
                 msgstr, _ = parse_noqa(msgstr)
 
-            if msgstr.strip() == '':
+            if not msgstr.strip():
                 # as-of-yet untranslated
                 node['translated'] = False
                 continue
@@ -393,8 +435,14 @@ class Locale(SphinxTransform):
             if isinstance(node, LITERAL_TYPE_NODES):
                 msgstr = '::\n\n' + indent(msgstr, ' ' * 3)
 
-            patch = publish_msgstr(self.app, msgstr, source,
-                                   node.line, self.config, settings)  # type: ignore[arg-type]
+            patch = publish_msgstr(
+                self.app,
+                msgstr,
+                source,
+                node.line,  # type: ignore[arg-type]
+                self.config,
+                settings,
+            )
             # FIXME: no warnings about inconsistent references in this part
             # XXX doctest and other block markup
             if not isinstance(patch, nodes.paragraph):
@@ -408,11 +456,21 @@ class Locale(SphinxTransform):
                 for _id in node['ids']:
                     term, first_classifier = split_term_classifiers(msgstr)
                     patch = publish_msgstr(
-                        self.app, term or '', source, node.line, self.config, settings,  # type: ignore[arg-type]
+                        self.app,
+                        term or '',
+                        source,
+                        node.line,  # type: ignore[arg-type]
+                        self.config,
+                        settings,
                     )
                     updater.patch = make_glossary_term(
-                        self.env, patch, first_classifier,
-                        source, node.line, _id, self.document,  # type: ignore[arg-type]
+                        self.env,
+                        patch,
+                        first_classifier,
+                        source,
+                        node.line,  # type: ignore[arg-type]
+                        _id,
+                        self.document,
                     )
                     processed = True
 
@@ -474,8 +532,14 @@ class Locale(SphinxTransform):
                 # This generates: <section ...><title>msgstr</title></section>
                 msgstr = msgstr + '\n' + '=' * len(msgstr) * 2
 
-            patch = publish_msgstr(self.app, msgstr, source,
-                                   node.line, self.config, settings)  # type: ignore[arg-type]
+            patch = publish_msgstr(
+                self.app,
+                msgstr,
+                source,
+                node.line,  # type: ignore[arg-type]
+                self.config,
+                settings,
+            )
             # Structural Subelements phase2
             if isinstance(node, nodes.title):
                 # get <title> node that placed as a first child
@@ -483,8 +547,8 @@ class Locale(SphinxTransform):
 
             # ignore unexpected markups in translation message
             unexpected: tuple[type[nodes.Element], ...] = (
-                nodes.paragraph,    # expected form of translation
-                nodes.title,        # generated by above "Subelements phase2"
+                nodes.paragraph,  # expected form of translation
+                nodes.title,  # generated by above "Subelements phase2"
             )
 
             # following types are expected if
@@ -527,7 +591,13 @@ class Locale(SphinxTransform):
                             msgstr = part
                         msgstr_parts.append(msgstr)
 
-                    new_entry = entry_type, ';'.join(msgstr_parts), target_id, main, None
+                    new_entry = (
+                        entry_type,
+                        ';'.join(msgstr_parts),
+                        target_id,
+                        main,
+                        None,
+                    )
                     new_entries.append(new_entry)
 
                 node['raw_entries'] = entries
@@ -535,14 +605,13 @@ class Locale(SphinxTransform):
 
 
 class TranslationProgressTotaliser(SphinxTransform):
-    """
-    Calculate the number of translated and untranslated nodes.
-    """
+    """Calculate the number of translated and untranslated nodes."""
 
     default_priority = 25  # MUST happen after Locale
 
     def apply(self, **kwargs: Any) -> None:
         from sphinx.builders.gettext import MessageCatalogBuilder
+
         if isinstance(self.app.builder, MessageCatalogBuilder):
             return
 
@@ -559,14 +628,13 @@ class TranslationProgressTotaliser(SphinxTransform):
 
 
 class AddTranslationClasses(SphinxTransform):
-    """
-    Add ``translated`` or ``untranslated`` classes to indicate translation status.
-    """
+    """Add ``translated`` or ``untranslated`` classes to indicate translation status."""
 
     default_priority = 950
 
     def apply(self, **kwargs: Any) -> None:
         from sphinx.builders.gettext import MessageCatalogBuilder
+
         if isinstance(self.app.builder, MessageCatalogBuilder):
             return
 
@@ -582,8 +650,10 @@ class AddTranslationClasses(SphinxTransform):
             add_translated = False
             add_untranslated = True
         else:
-            msg = ('translation_progress_classes must be '
-                   'True, False, "translated" or "untranslated"')
+            msg = (
+                'translation_progress_classes must be '
+                'True, False, "translated" or "untranslated"'
+            )
             raise ConfigError(msg)
 
         for node in NodeMatcher(nodes.Element, translated=Any).findall(self.document):
@@ -596,14 +666,13 @@ class AddTranslationClasses(SphinxTransform):
 
 
 class RemoveTranslatableInline(SphinxTransform):
-    """
-    Remove inline nodes used for translation as placeholders.
-    """
+    """Remove inline nodes used for translation as placeholders."""
 
     default_priority = 999
 
     def apply(self, **kwargs: Any) -> None:
         from sphinx.builders.gettext import MessageCatalogBuilder
+
         if isinstance(self.app.builder, MessageCatalogBuilder):
             return
 
